.. _user:

#################
gm3dh5 User Guide
#################

This guide is an overview and explains the important features;
details are found in :ref:`reference`.

.. toctree::
   :caption: Getting Started
   :maxdepth: 1

   installation
   ../release

   
.. toctree::
   :caption: The GrainMapper3D Result File
   :maxdepth: 2
   
   fileformat/index
   fileformat/conventions
   

.. toctree::
   :caption: Tutorials
   :maxdepth: 1
   
   neper/index
   
